@@ -1,5 +1,5 @@
 # MATT - A Framework For Modifying And Testing Topologies
-# Copyright (C) 2020 Jeff Raffael Gower
+# Copyright (C) 2021 Jeff Raffael Gower
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,8 +14,22 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <https://www.gnu.org/licenses/>.
 class Node:
+    """
+    Node class representing nodes on a topology tree
+    """
 
     def __init__(self, id, length, total_length, parent=None, l_child=None, r_child=None, name=None, bootstrap=None):
+        """
+        Initialises the node
+        :param id:
+        :param length:
+        :param total_length:
+        :param parent:
+        :param l_child:
+        :param r_child:
+        :param name:
+        :param bootstrap:
+        """
         self.id = id
         self.length = length
         self.total_length = total_length
@@ -25,4 +39,4 @@ class Node:
         self.name = name
         self.bootstrap = bootstrap
 
-# TODO lenghts simultaneously increased via node function
\ No newline at end of file
+# TODO lenghts simultaneously increased via node function
